@@ -1,23 +1,33 @@
-InterpretationMethod = R6::R6Class("InterpretationMethod",
+#' Interpretation Method
+#'
+#' @description Superclass container for Interpretation Method objects
+#'
+#' @export
+InterpretationMethod <- R6Class("InterpretationMethod",
   public = list(
-    # The aggregated results of the experiment
-    results = NULL,
-    # The prediction model
-    predictor = NULL,
+
+    #' @description Create an InterpretationMethod object
+    #' @template predictor
+    initialize = function(predictor) {
+      checkmate::assert_class(predictor, "Predictor")
+      self$predictor <- predictor
+      private$sampler <- predictor$data
+      private$getData <- private$sampler$get.x
+    },
+
+    #' @description Plot function. Calls `private$generatePlot()` of the
+    #' respective subclass.
+    #' @param ... Passed to `private$generatePlot()`.
     plot = function(...) {
-      private$plotData = private$generatePlot(...)
+      private$plotData <- private$generatePlot(...)
       if (!is.null(private$plotData)) {
         return(private$plotData)
       } else {
         warning("call run() first!")
       }
     },
-    initialize = function(predictor) {
-      checkmate::assert_class(predictor, "Predictor")
-      self$predictor = predictor
-      private$sampler = predictor$data
-      private$getData = private$sampler$get.x
-    },
+
+    #' @description Printer for InterpretationMethod objects
     print = function() {
       cat("Interpretation method: ", class(self)[1], "\n")
       private$printParameters()
@@ -29,10 +39,19 @@ InterpretationMethod = R6::R6Class("InterpretationMethod",
       if (!is.null(self$results)) {
         print(head(self$results))
       }
-    }
+    },
+
+    #' @field results [data.frame]\cr
+    #' The aggregated results of the experiment
+    results = NULL,
+    # The prediction model
+
+    #' @field predictor
+    #' Predictor object.
+    predictor = NULL
   ),
+
   private = list(
-    parallel = FALSE,
     # The sampling object for sampling from X
     sampler = NULL,
     # Wrapper for sampler
@@ -57,43 +76,36 @@ InterpretationMethod = R6::R6Class("InterpretationMethod",
     finished = FALSE,
     # Removes experiment results as preparation for running experiment again
     flush = function() {
-      private$dataSample = NULL
-      private$dataDesign = NULL
-      private$qResults = NULL
-      self$results = NULL
-      private$finished = FALSE
-    }, 
+      private$dataSample <- NULL
+      private$dataDesign <- NULL
+      private$qResults <- NULL
+      self$results <- NULL
+      private$finished <- FALSE
+    },
     run = function(force = FALSE, ...) {
       if (force) private$flush()
       if (!private$finished) {
         # DESIGN experiment
-        private$dataSample = private$getData()
-        private$dataDesign = private$intervene()
+        private$dataSample <- private$getData()
+        private$dataDesign <- private$intervene()
         # EXECUTE experiment
-        private$qResults = private$run.prediction(private$dataDesign)
+        private$qResults <- private$run.prediction(private$dataDesign)
         # AGGREGATE measurements
-        self$results = data.frame(private$aggregate())
-        private$finished = TRUE
+        self$results <- data.frame(private$aggregate())
+        private$finished <- TRUE
       }
     },
     run.prediction = function(dataDesign) {
-      private$predictResults = self$predictor$predict(data.frame(dataDesign))
-      private$multiClass = ifelse(ncol(private$predictResults) > 1, TRUE, FALSE)
+      private$predictResults <- self$predictor$predict(data.frame(dataDesign))
+      private$multiClass <- ifelse(ncol(private$predictResults) > 1, TRUE, FALSE)
       private$q(private$predictResults)
     },
-    get.parallel.fct = function(parallel = FALSE) {
-      if(parallel) {
-        foreach::`%dopar%`
-      } else {
-        foreach::`%do%`
-      }
-    },
     # The data need for plotting of results
     plotData = NULL,
     # Function to generate the plot
     generatePlot = function() NULL,
     # Feature names of X
-    feature.names = NULL, 
+    feature.names = NULL,
     printParameters = function() {}
   )
 )
